@@ -2,16 +2,16 @@ from .run_inference import run_inference
 import torch
 import pyro.distributions as distr
 import pickle
+import os
 
 class Simulate():
     def __init__(self, N=200, T=5, K=15, mean_loc=50, mean_scale=1000, var_scale=100, var_constr=100, 
-        noise_loc=0, noise_scale=1, eta=1, cov_type="diag", random_state=25):
+        noise_loc=0, noise_scale=1, eta=1, cov_type="diag", random_state=25, label=""):
         self.settings = {"N":N, "T":T, "K":K, "mean_loc":mean_loc, "mean_scale":mean_scale,
             "var_scale":var_scale, "eta":eta, "var_constr":var_constr, 
             "noise_loc":float(noise_loc), "noise_scale":float(noise_scale)}
         self.cov_type = cov_type
-        self.sim_id = ".".join(["N"+str(N), "T"+str(T), "K"+str(K), 
-            "m_loc"+str(mean_loc), "m_scale"+str(mean_scale), "v_scale"+str(var_scale)])
+        self.sim_id = ".".join(["N"+str(N), "T"+str(T), "K"+str(K), str(label)])
 
     def generate_dataset(self):
         K = self.settings["K"]
@@ -50,7 +50,7 @@ class Simulate():
             while torch.any(x[n,:] < 0):
                 x[n,:] = distr.MultivariateNormal(loc=mean[z[n]], scale_tril=Sigma[z[n]]).sample()
 
-        self.dataset = self._add_noise(x)
+        self.dataset = x
         self.params = {"weights":weights, "mean":mean, "sigma_vector":sigma_vector, "z":z}
 
 
@@ -66,36 +66,45 @@ class Simulate():
         return Sigma
 
 
-    def _add_noise(self, x):
-        noise_loc = self.settings["noise_loc"]
-        noise_scale = self.settings["noise_scale"]
-        N = self.settings["N"]
-        T = self.settings["T"]
+    # def _add_noise(self, x):
+    #     noise_loc = self.settings["noise_loc"]
+    #     noise_scale = self.settings["noise_scale"]
+    #     N = self.settings["N"]
+    #     T = self.settings["T"]
 
-        noise = torch.normal(mean=torch.full((N,T),noise_loc), std=torch.full((N,T),noise_scale)).abs()
+    #     noise = torch.normal(mean=torch.full((N,T),noise_loc), std=torch.full((N,T),noise_scale)).abs()
 
-        return torch.ceil(x.add_(noise)).int()
+    #     return torch.ceil(x.add_(noise)).int()
 
-    def run_inference_sim(self):
-        k_interval = [max(self.settings["K"]-5, 1), self.settings["K"]+5]
-        inference = run_inference(self.dataset, lineages=[], k_interval=k_interval, n_runs=2)
-        return inference
+    # def run_inference_sim(self, sim_id, n_runs):
+    #     k_interval = [max(self.settings["K"]-5, 1), self.settings["K"]+5]
+        
+    #     for run in range(n_runs):
+    #         new_sim_id = sim_id + "." + str(run)
+    #         new_sim = run_inference(self.dataset, lineages=[], k_interval=k_interval, n_runs=n_runs)
+    #     return inference
 
 
-def generate_synthetic_data(N_range, T_range, K_range, mean_loc_range, mean_scale_range, var_scale_range):
 
-    for N in N_range:
-        for T in T_range:
-            for K in K_range:
-                for mean_loc in mean_loc_range:
-                    for mean_scale in mean_scale_range:
-                        for var_scale in var_scale_range:
-                            sim = Simulate(N, T, K, mean_loc, mean_scale, var_scale) 
-                            sim.generate_dataset() 
-                            inf = sim.run_inference_sim()
-                            
-                            with open(sim.sim_id+".df.pkl", 'wb') as sim_file:
-                                pickle.dump(sim, sim_file)
+def generate_synthetic_data(N_values, T_values, K_values, n_datasets=1, check_present=True):
+    files_list = [f for f in os.listdir('.') if os.path.isfile(f)]
+
+    for n_df in range(n_datasets):
+        for N in N_values:
+            for T in T_values:
+                for K in K_values:
+                    mean_loc = 50
+                    mean_scale = 500
+                    var_scale = 400
+                    sim = Simulate(N, T, K, mean_loc, mean_scale, var_scale, label=n_df)
+
+                    # check if the file is already present
+                    if sim.sim_id+".data.pkl" in files_list and check_present:
+                        continue
+
+                    sim.generate_dataset() 
+                    
+                    # save the file in the current directory
+                    with open(sim.sim_id+".data.pkl", 'wb') as sim_file:
+                        pickle.dump(sim, sim_file)
 
-                            with open(sim.sim_id+".run.pkl", 'wb') as inf_file:
-                                pickle.dump(inf, inf_file)
